<?php
/** Lingala (lingála)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bombo (on ln.wikipedia.org)
 * @author Eruedin
 * @author Moyogo
 */

$fallback = 'fr';

// Remove French aliases
$namespaceGenderAliases = [];

$linkPrefixExtension = true;

# Same as the French (bug 8485)
$separatorTransformTable = [ ',' => "\xc2\xa0", '.' => ',' ];

